Module rust_corosync::cfg[][src]

cfg is the internal configuration and information library for corosync, it is mainly used by internal tools but may also contain API calls useful to some applications that need detailed information about or control of the operation of corosync and the cluster.

Structs

Callbacks

Callback from track_start. Will be called if another process requests to shut down corosync. reply_to_shutdown should be called with a ShutdownReply of either Yes or No.

Handle

A handle into the cfg library. returned from initialize and needed for all other calls

LinkStatus

Status of a link inside NodeStatus struct

NodeStatus

Structure returned from node_status_get, shows all the details of a node that is known to corosync, including all configured links

Enums

NodeStatusVersion

Version of the NodeStatus structure returned from node_status_get

ShutdownFlags

Flags for try_shutdown

ShutdownReply

Responses for reply_to_shutdown

TrackFlags

Trackflags for track_start. None currently supported

Functions

dispatch

Call any/all active CFG callbacks for this Handle see DispatchFlags for details

fd_get

Returns a file descriptor to use for poll/select on the CFG handle

finalize

Finish with a connection to corosync, after calling this the Handle is invalid

initialize

Initialize a connection to the cfg library. You must call this before doing anything else and use the passed back Handle. Remember to free the handle using finalize when finished.

kill_node

Tell another cluster node to shutdown. reason is a string that will be written to the system log files.

local_get

Get the local NodeId

node_status_get

Get the extended status of a node in the cluster (including active links) from its NodeId. Returns a filled in NodeStatus struct

reload_cnfig

Reload the cluster configuration on all nodes

reopen_log_files

Re-open the cluster log files, on this node only

reply_to_shutdown

Reply to a shutdown request with Yes or No ShutdownReply

track_start

Start tracking for shutdown notifications

track_stop

Stop tracking for shutdown notifications

try_shutdown

Ask this cluster node to shutdown. If ShutdownFlags is set to Request then it may be refused by other applications that have registered for shutdown callbacks.