Function rust_corosync::cfg::initialize[][src]

pub fn initialize(callbacks: &Callbacks) -> Result<Handle>
Initialize a connection to the cfg library. You must call this before doing anything else and use the passed back Handle. Remember to free the handle using finalize when finished.