Function rust_corosync::cfg::try_shutdown
source · [−]pub fn try_shutdown(handle: Handle, flags: ShutdownFlags) -> Result<()>Expand description
Ask this cluster node to shutdown. If ShutdownFlags is set to Request then it may be refused by other applications that have registered for shutdown callbacks.