Struct rust_corosync::cfg::NodeStatus
source · pub struct NodeStatus {
pub version: NodeStatusVersion,
pub nodeid: NodeId,
pub reachable: bool,
pub remote: bool,
pub external: bool,
pub onwire_min: u8,
pub onwire_max: u8,
pub onwire_ver: u8,
pub link_status: Vec<LinkStatus>,
}Expand description
Structure returned from node_status_get, shows all the details of a node that is known to corosync, including all configured links
Fields
version: NodeStatusVersionnodeid: NodeIdreachable: boolremote: boolexternal: boolonwire_min: u8onwire_max: u8onwire_ver: u8link_status: Vec<LinkStatus>Trait Implementations