Function rust_corosync::cmap::context_get [−][src]
pub fn context_get(handle: Handle) -> Result<u64>Expand description
Get the current ‘context’ value for this handle The context value is an arbitrary value that is always passed back to callbacks to help identify the source