Function rust_corosync::cmap::dispatch
source · [−]pub fn dispatch(handle: Handle, flags: DispatchFlags) -> Result<()>Expand description
Dispatch any/all active CMAP callbacks. Takes a Handle as returned from initialize, flags DispatchFlags tells it how many items to dispatch before returning