Function rust_corosync::cmap::set_number
source · [−]Expand description
Function to set a generic numeric value This doesn’t work for strings or binaries
Function to set a generic numeric value This doesn’t work for strings or binaries