Struct rust_corosync::cmap::CmapIterStart
source · [−]pub struct CmapIterStart { /* private fields */ }Expand description
Create one of these to start iterating over cmap values.
Implementations
sourceimpl CmapIterStart
impl CmapIterStart
sourcepub fn new(cmap_handle: Handle, prefix: &str) -> Result<CmapIterStart>
pub fn new(cmap_handle: Handle, prefix: &str) -> Result<CmapIterStart>
Create a new CmapIterStart object for iterating over a list of cmap keys