Struct rust_corosync::cpg::CpgIterStart
source · [−]pub struct CpgIterStart { /* private fields */ }Expand description
An object to iterate over a list of CPG groups, create one of these and then use ‘for’ over it
Implementations
sourceimpl CpgIterStart
impl CpgIterStart
sourcepub fn new(
cpg_handle: Handle,
group: &str,
iter_type: CpgIterType
) -> Result<CpgIterStart>
pub fn new(
cpg_handle: Handle,
group: &str,
iter_type: CpgIterType
) -> Result<CpgIterStart>
Create a new CpgIterStart object for iterating over a list of active CPG groups