Module rust_corosync::quorum [−][src]
Quorum provides basic information about the quorate state of the cluster with callbacks when nodelists change.
Structs
A handle into the quorum library. Returned from initialize and needed for all other calls
Data for model1 initialize
RingId returned in quorum_notification_fn
Enums
Flags for initialize, none currently supported
Data for model1 initialize
Value returned from initialize. Indicates whether quorum is currently active on this cluster.
Functions
Get the current ‘context’ value for this handle. The context value is an arbitrary value that is always passed back to callbacks to help identify the source
Set the current ‘context’ value for this handle. The context value is an arbitrary value that is always passed back to callbacks to help identify the source. Normally this is set in initialize, but this allows it to be changed
Display any/all active QUORUM callbacks for this Handle, see DispatchFlags for details
Return a file descriptor to use for poll/select on the QUORUM handle
Finish with a connection to corosync
Return the quorate status of the cluster
Initialize a connection to the quorum library. You must call this before doing anything else and use the passed back Handle. Remember to free the handle using finalize when finished.
Track node and quorum changes
Stop tracking node and quorum changes