Function rust_corosync::quorum::context_get
source · [−]Expand description
Get the current ‘context’ value for this handle. The context value is an arbitrary value that is always passed back to callbacks to help identify the source