pub enum NodeState {
Member,
Dead,
Leaving,
Unknown,
}
Current state of a node in the cluster, part of the NodeInfo and Node structs
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.