Function rust_corosync::votequorum::qdevice_poll
source · [−]Expand description
Poll a quorum device This must be done more often than the qdevice timeout (default 10s) while the device is active and the RingId must match the current value returned from the callbacks for it to be accepted.