Function rust_corosync::votequorum::set_expected
source · [−]Expand description
Set the current expected_votes for the cluster, this value must be valid and not result in an inquorate cluster.
Set the current expected_votes for the cluster, this value must be valid and not result in an inquorate cluster.