Struct rust_corosync::cpg::CpgIterStart [−][src]
pub struct CpgIterStart { /* fields omitted */ }Expand description
An object to iterate over a list of CPG groups, create one of these and then use ‘for’ over it
Implementations
Create a new CpgIterStart object for iterating over a list of active CPG groups