Enum rust_corosync::DispatchFlags[][src]

pub enum DispatchFlags {
    One,
    All,
    Blocking,
    OneNonblocking,
}
Flags to use with dispatch functions, eg cpg::dispatch One will dispatch a single callback (blocking) and return. All will loop trying to dispatch all possible callbacks. Blocking is like All but will block between callbacks. OneNonBlocking will dispatch a single callback only if one is available, otherwise it will return even if no callback is available.

Variants

One
All
Blocking
OneNonblocking