Module rust_corosync::quorum[][src]

Quorum provides basic information about the quorate state of the cluster with callbacks when nodelists change.

Structs

Handle

A handle into the quorum library. Returned from initialize and needed for all other calls

Model1Data

Data for model1 initialize

RingId

RingId returned in quorum_notification_fn

Enums

Model1Flags

Flags for initialize, none currently supported

ModelData

Data for model1 initialize

QuorumType

Value returned from initialize. Indicates whether quorum is currently active on this cluster.

Functions

context_get

Get the current ‘context’ value for this handle. The context value is an arbitrary value that is always passed back to callbacks to help identify the source

context_set

Set the current ‘context’ value for this handle. The context value is an arbitrary value that is always passed back to callbacks to help identify the source. Normally this is set in initialize, but this allows it to be changed

dispatch

Display any/all active QUORUM callbacks for this Handle, see DispatchFlags for details

fd_get

Return a file descriptor to use for poll/select on the QUORUM handle

finalize

Finish with a connection to corosync

getquorate

Return the quorate status of the cluster

initialize

Initialize a connection to the quorum library. You must call this before doing anything else and use the passed back Handle. Remember to free the handle using finalize when finished.

trackstart

Track node and quorum changes

trackstop

Stop tracking node and quorum changes